body{background:#FFF;color:#000;font:12px/1.5em "Lucida Grande",Helvetica,Arial,sans-serif;margin:8px;}
h1{font-size:2em}
h2{font-size:1.5em}
h3{font-size:1.17em}
h4{font-size:1em}
h5{font-size:.83em}
h6{font-size:.75em}
pre{font-family:Consolas,Monaco,monospace;}
.mceItemTable,.mceItemTable td,.mceItemTable th,.mceItemTable caption,.mceItemVisualAid{border:1px dashed #BBB;}
a.mceItemAnchor,img.mceItemAnchor{background:url(img/items.gif) no-repeat;width:12px;}
a.mceItemAnchor{background-position:bottom left;line-height:6px;overflow:hidden;padding-left:12px;}
img.mceItemAnchor{height:12px;}
img{border:0;}
table{cursor:default;}
table td,table th{cursor:text}
ins{border-bottom:1px solid #690;text-decoration:none;color:green;}
del{color:#900;text-decoration:line-through;}
cite{border-bottom:1px dashed #36C;}
abbr,acronym{border-bottom:1px dotted #ccc;cursor:help}
