/* Generic */
body{background:#efefef;font:12px'Lucida Grande',Helvetica,Arial,sans-serif;margin:8px 8px 0 8px;padding:0;}
a:link,a:visited{color:#000;}
a:hover{color:#2B6FB6;}
/* Forms */
fieldset{border:1px solid #919B9C;margin:0;padding:4px;}
legend{color:#2B6FB6;font-weight:bold;}
label.msg{display:none;}
label.invalid{color:#900;display:inline;}
input,select,textarea{border:1px solid #ccc;font:12px'Lucida Grande',Helvetica,Arial,sans-serif;}
input.invalid{border-color:#900;}
input,select{padding:2px 4px;}
input.radio,input.checkbox{border:1px none #000;background:transparent;vertical-align:middle;}
.input_noborder{border:0;}
textarea{font:12px/1.5em Consolas,Monaco,monospace !important;padding:5px 0 5px 5px;resize:none;}
/* Buttons */
#insert,#cancel,input.button,.updateButton{border:0;margin:0;padding:0;cursor:pointer;padding-bottom:2px;}
#insert,#cancel{padding:3px 6px;}
#insert{background:url('img/button-bg.png') repeat-x;border:1px solid #9a9a9a;border-radius:2px;float:right;}
#cancel{background:transparent;padding:5px 8px;text-decoration:underline;}
/* Browse */
a.browse span{display:block;width:20px;height:18px;background:url('img/button-bg.png');border:1px solid #FFF;margin-left:1px;}
.mceOldBoxModel a.browse span{width:22px;height:20px;}
a.browse:hover span{border:1px solid #0A246A;background-color:#B2BBD0;}
a.browse span.disabled{border:1px solid white;-moz-opacity:0.3;opacity:0.3;filter:progid:DXImageTransform.Microsoft.Alpha(opacity=30);}
a.browse:hover span.disabled{border:1px solid white;background-color:transparent;}
a.pickcolor span{display:block;width:20px;height:16px;background:url(img/icons.png) -840px 0;margin-left:2px;}
.mceOldBoxModel a.pickcolor span{width:21px;height:17px;}
a.pickcolor:hover span{background-color:#B2BBD0;}
a.pickcolor:hover span.disabled{}
/* Charmap */
table.charmap{border:1px solid #AAA;text-align:center}
td.charmap,#charmap a{width:18px;height:18px;color:#000;border:1px solid #AAA;text-align:center;font-size:12px;vertical-align:middle;line-height:18px;}
#charmap a{display:block;color:#000;text-decoration:none;border:0}
#charmap a:hover{background:#CCC;color:#2B6FB6}
#charmap #codeN{font:11px'Lucida Grande',Helvetica,Arial,sans-serif;}
#charmap #codeV{font-size:40px;height:80px;border:1px solid #AAA;text-align:center}
/* Source */
.wordWrapCode{vertical-align:middle;border:1px none #000000;background:transparent;}
.mceActionPanel{margin-top:5px;overflow:hidden;padding-right:5px;text-align:right;}
/* Tabs classes */
.tabs{width:100%;height:18px;line-height:normal;}
.tabs ul{margin:0;padding:0;list-style:none;}
.tabs li{float:left;margin:0 2px 0 0;padding:0 0 0 10px;line-height:17px;height:18px;display:block;}
.tabs li.current{margin-right:2px;}
.tabs span{float:left;display:block;padding:0px 10px 0 0;}
.tabs a{text-decoration:none;font:bold 12px'Lucida Grande',Helvetica,Arial,sans-serif;}
.tabs a:link,.tabs a:visited,.tabs a:hover{color:black;}
/* Panels */
.panel_wrapper div.panel{display:none;}
.panel_wrapper div.current{display:block;width:100%;height:300px;overflow:visible;}
.panel_wrapper{border-top:0px;padding:10px;padding-top:5px;clear:both;}
/* Columns */
.column{float:left;}
.properties{width:100%;}
.properties .column2{text-align:left;}
/* Titles */
h1,h2,h3,h4{color:#2B6FB6;margin:0;padding:0;padding-top:5px;}
h3{font-size:14px;}
.title{font-size:12px;font-weight:bold;color:#333;}
/* Dialog specific */
#link .panel_wrapper,#link div.current{height:125px;}
#link label,#image label{display:block;text-align:right;}
#link label:after,#image label:after{content:':';}
#image .panel_wrapper,#image div.current{height:220px;}
#plugintable thead{font-weight:bold;background:#DDD;}
#plugintable,#about #plugintable td{border:1px solid #919B9C;}
#plugintable{width:96%;margin-top:10px;}
#pluginscontainer{height:290px;overflow:auto;}
#colorpicker #preview{float:right;width:50px;height:14px;line-height:1px;border:1px solid black;margin-left:5px;}
#colorpicker #colors{float:left;border:1px solid gray;cursor:crosshair;}
#colorpicker #light{border:1px solid gray;margin-left:5px;float:left;width:15px;height:150px;cursor:crosshair;}
#colorpicker #light div{overflow:hidden;}
#colorpicker #previewblock{float:right;padding-left:10px;height:20px;}
#colorpicker .panel_wrapper div.current{height:175px;}
#colorpicker #namedcolors{width:150px;}
#colorpicker #namedcolors a{display:block;float:left;width:10px;height:10px;margin:1px 1px 0 0;overflow:hidden;}
#colorpicker #colornamecontainer{margin-top:5px;}
#colorpicker #picker_panel fieldset{margin:auto;width:325px;}
#filebrowser_link, #srcbrowser_link, #hrefbrowser_link {text-decoration:none;}
