body {
    direction: rtl;
    font-size: 14px;
    line-height: 17px;
}
/* base */
.object-tools li {
    float: right;
    margin: 0 5px 0 0;
}
ul.messagelist li, ul.messagelist li.success {
    background-position: 99% 50%;
    padding: 5px 30px 5px 0;
}
/* LOGIN */
.login .form-row label {
    float: right;
    padding-left: 0.5em;
    padding-right: 0;
}
.login .submit-row input {
    margin-left: -1px;
    margin-right: 8px;
}
/* GLOBAL */

th {
    text-align: right;
}
.module h2, .module caption {
    text-align: right;
}
.addlink, .changelink {
    padding-left: 0px;
    padding-right: 12px;
    background-position: 100% 0.2em;
}
.deletelink {
    padding-left: 0px;
    padding-right: 12px;
    background-position: 100% 0.25em;
}
.object-tools {
    float: left;
}
/* LAYOUT */

#user-tools li, .admin-title {
    border-left: 1px solid #262626;
    border-right: 1px solid #404040;
}
.admin-title {
    float: right;
}
#user-tools {
    float: left;
    border-left: 0;
    border-right: 1px solid #262626;
}
#header ul li {
    float: right;
}
div.breadcrumbs {
    text-align: right;
    padding: 3px 15px 3px 8px;
}
#content-main {
    float: right;
}
#content-related {
    float: left;
    margin-left: -19em;
    margin-right: auto;
}
.colMS {
    margin-left: 20em !important;
    margin-right: 0 !important;
}
/* dashboard styles */

.dashboard .module table td a {
    padding-left: 0;
    margin-left: 0;
    padding-right: 14px;
    margin-right: 10px;
}
ul.actionlist li {
    padding: 2px 25px 0 10px;
    line-height: 16px;
}
ul.actionlist li a {
    padding-left: 0;
    margin-left: 0;
    padding-right: 13px;
    margin-right: -14px;
    background-position: 100% 50%;
}
ul.actionlist li.deletelink {
    background-position: 232px 5px;
}
/* changelists styles */

.change-list .filtered {
    background: white url(../img/admin/changelist-bg_rtl.gif) top left repeat-y !important;
}
.change-list .filtered table {
    border-left: 1px solid #ddd;
    border-right: 0px none;
}
#changelist-filter {
    float: right;
    margin-right: 0;
    margin-left: -10000px;
}
#changelist-filter li.selected {
    border-left: 0px none;
    padding-left: 0px;
    margin-left: 0;
    border-right: 5px solid #ccc;
    padding-right: 5px;
    margin-right: -10px;
}
#changelist.filtered .changelist-content {
    float: right;
    margin-right: 0;
    margin-left: 10px;
}
#changelist.module.filtered {
    padding-right: 0;
    padding-left: 210px;
}
#changelist .actions label {
    margin: -2px 5px -2px 0;
    padding: 5px 25px 7px 0;
    background-position: 100% 50%;
}
/* modules */

.module > h2, .module caption, .inline-group h2, .inline-related h2 {
    padding: 7px 10px 6px 5px;
}
/* tables */

#changelist table {
    margin-right: 0;
    border-right: none;
    margin-left: -1px;
    border-left: 1px solid #D4D4D4;
}
thead th, tfoot td {
    border-right: 1px solid #D4D4D4;
    border-left: none;
}
thead th:first-child, tfoot td:first-child {
    border-right: none;
}
#changelist tbody th, #changelist tbody td {
    border-right: 1px solid #E0E0E0;
    border-left: none;
}
#changelist tbody tr th:first-child, #changelist tbody tr td:first-child {
    border-right: none;
}
caption, th, td {
    text-align: right;
}
/* FORMS */

.aligned label {
    padding: 0 0 3px 10px;
    float: right;
}
.submit-row {
    text-align: right;
}
.submit-row p.deletelink-box, .submit-row p.cancellink-box {
    float: right;
    margin-right: 0;
    margin-left: 8px;
}
.submit-row .deletelink {
    background: url(../img/admin/icon_deletelink.gif) 0 50% no-repeat;
    padding-right: 14px;
}
.vDateField, .vTimeField {
    margin-left: 2px;
}
#id_slug {
    direction: ltr;
}
form ul.inline li {
    float: right;
    padding-right: 0;
    padding-left: 7px;
}
fieldset .field-box {
    float: right;
    margin-left: 20px;
}
.errorlist li {
    background-position: 100% .3em;
    padding: 4px 25px 4px 5px;
}
.errornote {
    background-position: 100% .3em;
    padding: 4px 25px 4px 5px;
}
#changelist-search input[type="submit"] {
    margin-left: 0;
    margin-right: 6px;
}
form .aligned p.help {
    margin: 2px 135px 0 0;
}
input[type="checkbox"], input[type="radio"] {
    margin: 0 130px 0 0;
}
ul.radiolist label input, ul.checkboxlist label input {
    margin: 0 0 0 2px;
    vertical-align: baseline;
}
.aligned .vCheckboxLabel {
    margin: 0 10px 0 0;
}
form .aligned input + label + p.help {
    margin: 0 158px 0 0;
}
.description {
    padding: 10px 15px 9px 0;
}
table input[type="checkbox"], table input[type="radio"] {
    margin-right: 0;
}
/* WIDGETS */

.calendarnav-previous {
    top: 0;
    left: auto;
    right: 0;
}
.calendarnav-next {
    top: 0;
    right: auto;
    left: 0;
}
.calendar caption, .calendarbox h2 {
    text-align: center;
}
.selector {
    float: right;
}
.selector .selector-filter {
    text-align: right;
}
.selector-available, .selector-chosen {
    float: right;
}
.selector ul.selector-chooser {
    float: right;
}
a.selector-add:link, a.selector-add:visited {
    background-image: url('../img/icons/icon-selector_remove-m2m_horizontal.png');
}
a.selector-add:hover, a.selector-add:active {
    background-image: url('../img/icons/icon-selector_remove-m2m_horizontal-hover.png');
}
a.selector-remove:link, a.selector-remove:visited {
    background-image: url('../img/icons/icon-selector_add-m2m_horizontal.png');
}
a.selector-remove:hover, a.selector-remove:active {
    background-image: url('../img/icons/icon-selector_add-m2m_horizontal-hover.png');
}
thead th, tfoot td {
    font-size: 16px;
    line-height: 19px;
}
.paginator {
    font-size: 14px;
    line-height: 17px;
}
#changelist-filter h2 {
    font-size: 16px;
    line-height: 19px;
}
#changelist-filter .filterset h3 {
    font-size: 14px;
    line-height: 17px;
}
.object-tools a {
    font-size: 16px;
}
#changelist-filter a {
    font-size: 14px;
    line-height: 17px;
}
.selector .selector-filter {
    background-position: 315px 50%;
}
.selector .selector-filter input[type=text] {
    margin: 0 25px 0 0;
}
/* typography */

a.addlink, a.changelink, a.deletelink {
    background-position: 100% 50%;
    margin: 0 10px -1px 0;
    padding: 1px 14px 0 0;
}
a.deletelink {
    margin: 0;
    font-size: 15px;
    line-height: 19px;
}
blockquote {
    margin-left: 0;
    margin-right: 2px;
    padding-left: 0;
    padding-right: 4px;
    border-left: none;
    border-right: 5px solid #ddd;
}
/* fonts */

h1 {
    font-size: 18px;
}
.module > h2, .module caption, .inline-group h2, .inline-related h2 {
    font-size: 16px;
    line-height: 19px;
}
label, th {
    font-size: 15px;
    line-height: 18px;
}
input, textarea, select, button {
    font-size: 15px;
}
input[type="submit"], input[type="button"], button {
    height: 28px;
}
#content-related h3, #content-related-extended h3,
#content-related h4, #content-related-extended h4 {
    font-size: 15px;
    line-height: 18px;
}
td {
    font-size: 14px;
    line-height: 17px;
}
#content-related, #content-related-extended {
    font-size: 14px;
    line-height: 17px;
}
select[name="site_id"] {
    font-size: 12px;
}
.help, p.help {
    font-size: 12px;
}
/* MISC */

.inline-related h2 {
    text-align: right
}
#changelist .submit-row {
    text-align: right;
}
#quick-blog input[type="submit"].default {
    float: left;
}
